#!/usr/bin/env python
# -*- coding: utf-8 -*-

__version__ = '0.8.0'
from .base import Choices
